==> apache-reef-0.11.0-incubating.tar.gz: apache-reef-0.11.0-incubating/lang/java/reef-tang/tang/src/test/java/org/apache/reef/tang/test/CyclicDependency.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.tang.test;

import javax.inject.Inject;

/**
 * Part of a cyclic dependency
 */
final class CyclicDependency {
  private final CyclicDependencyClassOne one;
  private final CyclicDependencyClassTwo two;

  @Inject
  CyclicDependency(final CyclicDependencyClassOne one,
                   final CyclicDependencyClassTwo two) {
    this.one = one;
    this.two = two;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;

    CyclicDependency that = (CyclicDependency) o;

    if (!one.equals(that.one)) return false;
    if (!two.equals(that.two)) return false;

    return true;
  }

  @Override
  public int hashCode() {
    int result = one.hashCode();
    result = 31 * result + two.hashCode();
    return result;
  }
}

==> apache-reef-0.12.0-incubating.tar.gz: apache-reef-0.12.0-incubating/lang/java/reef-tang/tang/src/test/java/org/apache/reef/tang/test/CyclicDependency.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.tang.test;

import javax.inject.Inject;

/**
 * Part of a cyclic dependency.
 */
final class CyclicDependency {
  private final CyclicDependencyClassOne one;
  private final CyclicDependencyClassTwo two;

  @Inject
  CyclicDependency(final CyclicDependencyClassOne one,
                   final CyclicDependencyClassTwo two) {
    this.one = one;
    this.two = two;
  }

  @Override
  public boolean equals(final Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }

    final CyclicDependency that = (CyclicDependency) o;

    if (!one.equals(that.one)) {
      return false;
    }
    if (!two.equals(that.two)) {
      return false;
    }

    return true;
  }

  @Override
  public int hashCode() {
    int result = one.hashCode();
    result = 31 * result + two.hashCode();
    return result;
  }
}
